workflow

package
v0.0.0-...-1c4df2c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 1, 2019 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Accept

func Accept(runtime settings.Runtime) error

Accept signifies that the rationale for a KEP has been accepted by a sponsoring SIG and that work is underway to design and document an approach to realize the value described by the introduction of a KEP. Currently Accept:

  • adds the principal as both an approver and reviewer
  • sets the KEP state to `provisional`
  • persists the KEP to disk

func Approve

func Approve(runtime settings.Runtime) error

Approve allows an approver to signal that a KEP is approved for implementation. The KEP is checked for consistency before the state is updated, which can return an error

func Init

func Init(runtime settings.Runtime) (string, error)

Init is responsible for minimizing the busy work of creating a KEP. Currently it:

  • creates the initial directory structure
  • placing KEPs created at the top level of KEP content in a `kubernetes-wide` directory
  • places KEPs created at the top level of a SIG directory in a `sig-wide` directory
  • creates initial metadata with required sections

Unlike other functions in workflow/ we need to return the path explicitly as it may have changed from Runtime.TargetDir() for SIG or Kubernetes wide KEPs

func Plan

func Plan(runtime settings.Runtime) error

Plan helps an author sketch out guides for

  • operators: who may be forced to interact with the enhancement in rage and want to understand how things can go wrong, how to know its working, and what other moving parts does this enhancement interact with
  • other developers: who need to review, comprehend, and extend the enhancement over its lifetime
  • teachers: documentation writers, technical trainers, writers, all want to understand how to talk about the enhancement

Guide templates are rendered and their locations added to the KEP metadata. Plan also adds a template for iterating on success criteria as the enhancement works towards general availability

func Propose

func Propose(runtime settings.Runtime) error

Propose prepares a KEP for initial proposal to the Kubernetes Community. The KEP process has been designed as an iterative process; taking inspiration from https://blog.golang.org/toward-go2, Propose prepares the author to explain the importance of their change through a KEP Propose currently:

  • sets KEP state to `draft`

Errors returned by Propose are likely due to file i/o Eventually, Propose may also handle git and GitHub operations

Types

This section is empty.

Jump to