Documentation
¶
Index ¶
- Constants
- func AddAuthorizationHeader(req *http.Request, token auth.TokenProvider) error
- func CreatePullRequest(routingInfo PullRequestRoutingInfo, prTitle PullRequestTitle, ...) (string, error)
- func Fork(token auth.TokenProvider, owner string, repo string) (string, error)
- func ForkUrl(owner string, repo string) string
- func GitUrl(owner string, repo string) string
- func HttpClient() *http.Client
- func PrUrl(owner string, repo string) string
- func RepoApiUrl(owner string, repo string) string
- type PullRequestDescription
- type PullRequestRoutingInfo
- type PullRequestTitle
- type SourceBranch
- type SourceOwner
- type SourceRepository
- type TargetBranch
- type TargetOwner
- type TargetRepository
Constants ¶
const (
AuthorizationHeaderName = "Authorization"
)
Variables ¶
This section is empty.
Functions ¶
func AddAuthorizationHeader ¶
func AddAuthorizationHeader(req *http.Request, token auth.TokenProvider) error
func CreatePullRequest ¶
func CreatePullRequest(routingInfo PullRequestRoutingInfo, prTitle PullRequestTitle, prDescription PullRequestDescription) (string, error)
func GitUrl ¶
GitUrl returns the URL to use for Git operations against a repo hosted on GitHub (e.g. clone, pu
func HttpClient ¶
func PrUrl ¶
PrUrl returns the URL to use when creating a pull request against a repo hosted on GitHub
func RepoApiUrl ¶
RepoApiUrl returns the URL to use when performing CRUD operations against a repo hosted on GitHu
Types ¶
type PullRequestDescription ¶
type PullRequestDescription string
type PullRequestRoutingInfo ¶
type PullRequestRoutingInfo interface {
Token() auth.TokenProvider
SourceRepositoryOwner() string
SourceRepository() string
SourceBranch() string
TargetRepositoryOwner() string
TargetRepository() string
TargetBranch() string
}
func NewPullRequestRoutingInfo ¶
func NewPullRequestRoutingInfo( token auth.TokenProvider, sourceOwner SourceOwner, sourceRepository SourceRepository, sourceBranch SourceBranch, targetOwner TargetOwner, targetRepository TargetRepository, targetBranch TargetBranch, ) PullRequestRoutingInfo
type PullRequestTitle ¶
type PullRequestTitle string
type SourceBranch ¶
type SourceBranch string
type SourceOwner ¶
type SourceOwner string
type SourceRepository ¶
type SourceRepository string
type TargetBranch ¶
type TargetBranch string
type TargetOwner ¶
type TargetOwner string
type TargetRepository ¶
type TargetRepository string
Source Files
¶
Click to show internal directories.
Click to hide internal directories.