Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Path ¶
Path returns the path to a possible KEP directory or an error if SIG routing information cannot be determined
example:
contentRoot := "/tmp/keps-sandbox/content" (1) kepDir, _ := Path(contentRoot, "large-value-delivered-incrementally") println(kepDir) // /tmp/keps-sandbox/content/kubernetes-wide/large-value-delivered-incrementally (2) kepDir, _ := Path(contentRoot, "/tmp/keps-sandbox/content/large-value-delivered-incrementally") println(kepDir) // /tmp/keps-sandbox/content/kubernetes-wide/large-value-delivered-incrementally (3) kepDir, _ := Path(contentRoot, "sig-node/functional-value-delivered-incrementally") println(kepDir) // /tmp/keps-sandbox/content/sig-node/sig-wide/functional-value-delivered-incrementally (4) kepDir, _ := Path(contentRoot, "/tmp/keps-sandbox/content/sig-node/sig-wide/functional-value-delivered-incrementally") println(kepDir) // /tmp/keps-sandbox/content/sig-node/sig-wide/functional-value-delivered-incrementally (5) kepDir, _ := Path(contentRoot, "sig-node/kubelet/kubelet-specific-value-delivered-incrementally") println(kepDir) // /tmp/keps-sandbox/content/sig-node/kubelet/kubelet-specific-value-delivered-incrementally (6) kepDir, _ := Path(contentRoot, "/tmp/keps-sandbox/content/sig-node/kubelet/kubelet-specific-value-delivered-incrementally") println(kepDir) // /tmp/keps-sandbox/content/sig-node/kubelet/kubelet-specific-value-delivered-incrementally an absolute path is returned with the intention of using the result as input to standard library calls to functions such as os.Open so that caller location is irrelevant
Types ¶
type Instance ¶
type Instance interface {
UniqueID() string
ShortID() int
Title() string
OwningSIG() string
Authors() []string
ContentDir() string
State() states.Name
Created() time.Time
LastUpdated() time.Time
Sections() []string
// simple pass through mutators
AddApprovers(...string)
AddReviewers(...string)
// heavy lifting mutators
SetState(states.Name) error
// consistency
AddChecks(...check.That)
Check() error
// flush to disk
Persist() error
}
Directories
¶
| Path | Synopsis |
|---|---|
|
Code generated by counterfeiter.
|
Code generated by counterfeiter. |
|
metadatafakes
Code generated by counterfeiter.
|
Code generated by counterfeiter. |
|
sectionsfakes
Code generated by counterfeiter.
|
Code generated by counterfeiter. |
Click to show internal directories.
Click to hide internal directories.